summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authoryaolu <yaolu@google.com>2016-10-15 00:08:56 +0000
committerandroid-build-merger <android-build-merger@google.com>2016-10-15 00:08:56 +0000
commitc8f2e1633f3ebe59f5f4da62ab56aa03d3d090d5 (patch)
tree310445d49da1746bcd55f13c4ea8258b529d78cc
parent8757d5aed6423a822a5f1699c44616dd33ecee69 (diff)
parent315f713dd33f50641771579772216fce0ca6472f (diff)
downloadpackages_apps_Contacts-c8f2e1633f3ebe59f5f4da62ab56aa03d3d090d5.tar.gz
packages_apps_Contacts-c8f2e1633f3ebe59f5f4da62ab56aa03d3d090d5.tar.bz2
packages_apps_Contacts-c8f2e1633f3ebe59f5f4da62ab56aa03d3d090d5.zip
Rename method in master to be consistent with h to fix build breakage
am: 315f713dd3 Change-Id: Ibc40ba6d893bdc99a23fd0fa37c0b867871b1c16
-rw-r--r--src/com/android/contacts/common/list/ContactListFilter.java10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/com/android/contacts/common/list/ContactListFilter.java b/src/com/android/contacts/common/list/ContactListFilter.java
index cdea37a6f..e99de4d23 100644
--- a/src/com/android/contacts/common/list/ContactListFilter.java
+++ b/src/com/android/contacts/common/list/ContactListFilter.java
@@ -394,11 +394,11 @@ public final class ContactListFilter implements Comparable<ContactListFilter>, P
/**
* Returns true if this ContactListFilter contains at least one Google account.
- * (see {@link #isWritableGoogleTypeFilter )
+ * (see {@link #isGoogleAccountType )
*/
public boolean isSyncable(List<AccountWithDataSet> accounts) {
// TODO(samchen): Check FILTER_TYPE_CUSTOM
- if (isWritableGoogleTypeFilter() && filterType == ContactListFilter.FILTER_TYPE_ACCOUNT) {
+ if (isGoogleAccountType() && filterType == ContactListFilter.FILTER_TYPE_ACCOUNT) {
return true;
}
if (filterType == ContactListFilter.FILTER_TYPE_ALL_ACCOUNTS
@@ -417,12 +417,12 @@ public final class ContactListFilter implements Comparable<ContactListFilter>, P
}
/**
* Returns the Google accounts (see {@link #isWritableGoogleTypeFilter ) for this ContactListFilter.
*/
public List<Account> getSyncableAccounts(List<AccountWithDataSet> accounts) {
final List<Account> syncableAccounts = new ArrayList<>();
// TODO(samchen): Check FILTER_TYPE_CUSTOM
- if (isWritableGoogleTypeFilter() && filterType == ContactListFilter.FILTER_TYPE_ACCOUNT) {
+ if (isGoogleAccountType() && filterType == ContactListFilter.FILTER_TYPE_ACCOUNT) {
syncableAccounts.add(new Account(accountName, accountType));
} else if (filterType == ContactListFilter.FILTER_TYPE_ALL_ACCOUNTS
|| filterType == ContactListFilter.FILTER_TYPE_DEFAULT) {
@@ -441,7 +441,7 @@ public final class ContactListFilter implements Comparable<ContactListFilter>, P
* Returns true if this ContactListFilter is Google account type. (i.e. where
* accountType = "com.google" and dataSet = null)
*/
- public boolean isWritableGoogleTypeFilter() {
+ public boolean isGoogleAccountType() {
return GoogleAccountType.ACCOUNT_TYPE.equals(accountType) && dataSet == null;
}
}
@@ -417,12 +417,12 @@ public final class ContactListFilter implements Comparable<ContactListFilter>, P
}
/**
- * Returns the Google accounts (see {@link #isWritableGoogleTypeFilter ) for this ContactListFilter.
+ * Returns the Google accounts (see {@link #isGoogleAccountType ) for this ContactListFilter.
*/
public List<Account> getSyncableAccounts(List<AccountWithDataSet> accounts) {